@@ -26,7 +26,7 @@ if shell is None:
     ipapp = TerminalIPythonApp()
     # Avoid output (banner, prints)
     ipapp.interact = False
-    ipapp.initialize([])
+    ipapp.initialize(['--no-term-title'])
     shell = ipapp.shell
 else:
     # Running inside IPython
@@ -134,12 +134,8 @@ def main():
         class Restart(Exception):
             pass
     
-    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['--help', '--command='])
+    opts, args = getopt.getopt(sys.argv[1:], 'hc:', ['help', 'command='])
 
-    if not args:
-        print(_usage)
-        sys.exit(2)
-    
     commands = []
     for opt, optarg in opts:
         if opt in ['-h', '--help']:
@@ -148,6 +144,10 @@ def main():
         elif opt in ['-c', '--command']:
             commands.append(optarg)
 
+    if not args:
+        print(_usage)
+        sys.exit(2)
+    
     mainpyfile = args[0]     # Get script filename
     if not os.path.exists(mainpyfile):
         print('Error:', mainpyfile, 'does not exist')
